#!/usr/bin/env python3
# Copyright (C) 2024 Spearhead Systems SRL

import copy
from cmk.gui.i18n import _
from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    HostRulespec,
    IndividualOrStoredPassword,
    RulespecGroupCheckParametersDiscovery,
    CheckParameterRulespecWithItem,
    RulespecGroupCheckParametersApplications,
)
from cmk.gui.watolib.rulespecs import Rulespec
from cmk.gui.valuespec import (
    Dictionary,
    TextInput,
    Integer,
    ListOfStrings,
    Password
)


def _valuespec_special_agents_azure_discovery():
    return Dictionary(
        title=_("Azure Discovery"),
        elements=[
            (
                "tenant",
                TextInput(
                    title=_("Tenant ID / Directory ID"),
                    allow_empty=False,
                    size=45,
                ),
            ),
            (
                "client",
                TextInput(
                    title=_("Client ID / Application ID"),
                    allow_empty=False,
                    size=45,
                ),
            ),
            (
                "secret",
                IndividualOrStoredPassword(
#                Password(
                    title=_("Client Secret"),
                    allow_empty=False,
                    size=45,
                ),
            ),
        ],
    )

def _valuespec_special_agents_azure_keyvault_metric_check():
    return Dictionary(
        title=_("Azure Key Vault Metric Checks"),
        optional_keys=["warn_percent", "crit_percent"],
        elements=[
            (
                "warn_percent",
                Integer(
                    minvalue=0,
                    default_value=98,
                    title=_("Warn when percentage falls below this threshold"),
                ),
            ),
            (
                "crit_percent",
                Integer(
                    minvalue=0,
                    default_value=90,
                    title=_("Warn when percentage falls below this threshold"),
                ),
            ),
        ],
    )

def _valuespec_special_agents_azure_firewall_metric_check():
    return _valuespec_special_agents_azure_keyvault_metric_check()


rulespec_registry.register(
    HostRulespec(
        name="special_agents:azure_keyvault_metrics",
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        valuespec=_valuespec_special_agents_azure_discovery,
    )
)
rulespec_registry.register(
    HostRulespec(
        name="special_agents:azure_firewall_metrics",
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        valuespec=_valuespec_special_agents_azure_discovery,
    )
)
rulespec_registry.register(
    HostRulespec(
        name="special_agents:azure_defender_alerts",
        group=RulespecGroupCheckParametersDiscovery,
        match_type='dict',
        valuespec=_valuespec_special_agents_azure_discovery,
    )
)

rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="azure_keyvault_metric",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_valuespec_special_agents_azure_keyvault_metric_check,
    )
)
rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name="azure_firewall_metric",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_valuespec_special_agents_azure_keyvault_metric_check,
    )
)

